MINOR: listener: split dequeue_all_listener() in two

We use it half times for the global_listener_queue and half times
for a proxy's queue and this requires the callers to take care of
these. Let's split it in two versions, the current one working only
on the global queue and another one dedicated to proxies for the
per-proxy queues. This cleans up quite a bit of code.
diff --git a/include/proto/listener.h b/include/proto/listener.h
index 2336e63..e8f9ece 100644
--- a/include/proto/listener.h
+++ b/include/proto/listener.h
@@ -57,8 +57,11 @@
  */
 int disable_all_listeners(struct protocol *proto);
 
-/* Dequeues all of the listeners waiting for a resource in wait queue <queue>. */
-void dequeue_all_listeners(struct mt_list *list);
+/* Dequeues all listeners waiting for a resource the global wait queue */
+void dequeue_all_listeners();
+
+/* Dequeues all listeners waiting for a resource in proxy <px>'s queue */
+void dequeue_proxy_listeners(struct proxy *px);
 
 /* Must be called with the lock held. Depending on <do_close> value, it does
  * what unbind_listener or unbind_listener_no_close should do.